@@ -27,26 +27,23 @@ LOG = logging.getLogger(__name__)
 
 
 class ZoneExportController(rest.RestController):
-
     @pecan.expose(template=None, content_type='text/dns')
     @utils.validate_uuid('export_id')
     def get_all(self, export_id):
         context = pecan.request.environ['context']
-        if policy.enforce_new_defaults():
-            target = {constants.RBAC_PROJECT_ID: context.project_id}
-        else:
-            target = {'tenant_id': context.project_id}
+        target = {constants.RBAC_PROJECT_ID: context.project_id,
+                  'tenant_id': context.project_id}
 
         policy.check('zone_export', context, target)
 
         export = self.central_api.get_zone_export(context, export_id)
 
         if export.location and export.location.startswith('designate://'):
-            return self.central_api.\
-                export_zone(context, export['zone_id'])
+            return self.central_api.export_zone(context, export['zone_id'])
         else:
-            msg = 'Zone can not be exported synchronously'
-            raise exceptions.BadRequest(msg)
+            raise exceptions.BadRequest(
+                'Zone can not be exported synchronously'
+            )
 
 
 class ZoneExportCreateController(rest.RestController):
