@@ -14,11 +14,12 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 import flask
-from oslo_config import cfg
 
 from designate.common import constants
+import designate.conf
 
-cfg.CONF.import_opt('enable_host_header', 'designate.api', group='service:api')
+
+CONF = designate.conf.CONF
 
 
 def _add_a_version(versions, version, api_url, status, timestamp):
@@ -38,18 +39,25 @@ def factory(global_config, **local_conf):
 
     @app.route('/', methods=['GET'])
     def version_list():
-        if cfg.CONF['service:api'].enable_host_header:
+        if CONF['service:api'].enable_host_header:
             url_root = flask.request.url_root
         else:
-            url_root = cfg.CONF['service:api'].api_base_uri
+            url_root = CONF['service:api'].api_base_uri
         api_url = url_root.rstrip('/') + '/v2'
 
         versions = []
         # Initial API version for v2 API
         _add_a_version(versions, 'v2', api_url, constants.SUPPORTED,
                        '2022-06-29T00:00:00Z')
-        _add_a_version(versions, 'v2.0', api_url, constants.CURRENT,
+        _add_a_version(versions, 'v2.0', api_url, constants.SUPPORTED,
                        '2022-06-29T00:00:00Z')
+        # 2.1 Shared Zones
+        _add_a_version(versions, 'v2.1', api_url, constants.SUPPORTED,
+                       '2023-01-25T00:00:00Z')
+
+        # 2.2 SVCB and HTTPS record types
+        _add_a_version(versions, 'v2.2', api_url, constants.CURRENT,
+                       '2025-08-25T00:00:00Z')
 
         return flask.jsonify({'versions': versions})
 
