@@ -19,23 +19,23 @@ import sys
 
 from alembic import command as alembic_command
 from alembic.config import Config
-from oslo_config import cfg
 from oslo_log import log as logging
 
+import designate.conf
 from designate.manage import base
 
-CONF = cfg.CONF
+CONF = designate.conf.CONF
 LOG = logging.getLogger(__name__)
 
 
 class DatabaseCommands(base.Commands):
     def _get_alembic_config(self, db_url=None, stringio_buffer=sys.stdout):
         alembic_dir = os.path.join(os.path.dirname(__file__),
-                                   os.pardir, 'storage/impl_sqlalchemy')
+                                   os.pardir, 'storage/sqlalchemy')
         alembic_cfg = Config(os.path.join(alembic_dir, 'alembic.ini'),
                              stdout=stringio_buffer)
         alembic_cfg.set_main_option(
-            'script_location', 'designate.storage.impl_sqlalchemy:alembic')
+            'script_location', 'designate.storage.sqlalchemy:alembic')
         if db_url:
             alembic_cfg.set_main_option('sqlalchemy.url', db_url)
         else:
@@ -73,7 +73,7 @@ class DatabaseCommands(base.Commands):
                                      stringio_buffer=latest_buffer))
         latest = latest_buffer.getvalue().replace('\n', ' ')
         latest_buffer.close()
-        print("Current: %s Latest: %s" % (current, latest))
+        print(f'Current: {current} Latest: {latest}')
 
     def sync(self, db_url=None, stringio_buffer=sys.stdout):
         alembic_command.upgrade(
