@@ -13,30 +13,30 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-
-from oslo_config import cfg
 from oslo_log import log as logging
 import oslo_messaging as messaging
+from oslo_utils import uuidutils
 import stevedore.exception
 import yaml
 
 from designate.backend import base as backend_base
 from designate.central import rpcapi as central_rpcapi
+import designate.conf
 from designate import exceptions
 from designate.manage import base
 from designate import objects
 from designate.objects.adapters import DesignateAdapter
 from designate import policy
 from designate import rpc
-from designate import utils
 
+
+CONF = designate.conf.CONF
 LOG = logging.getLogger(__name__)
-CONF = cfg.CONF
 
 
 class PoolCommands(base.Commands):
     def __init__(self):
-        super(PoolCommands, self).__init__()
+        super().__init__()
         self.central_api = None
         self.dry_run = False
         self.skip_verify_drivers = False
@@ -44,7 +44,7 @@ class PoolCommands(base.Commands):
     def _setup(self, dry_run=False, skip_verify_drivers=False):
         self.dry_run = dry_run
         self.skip_verify_drivers = skip_verify_drivers
-        rpc.init(cfg.CONF)
+        rpc.init(CONF)
         self.central_api = central_rpcapi.CentralAPI()
 
     @base.args('--file', help='The path to the file the yaml output should be '
@@ -67,22 +67,29 @@ class PoolCommands(base.Commands):
 
     @base.args('--pool_id', help='ID of the pool to be examined',
                default=CONF['service:central'].default_pool_id)
-    def show_config(self, pool_id):
+    @base.args('--all_pools', help='show the config of all the pools',
+               default=False, required=False, action='store_true')
+    def show_config(self, pool_id, all_pools):
         self._setup()
 
         self.output_message.append('Pool Configuration:')
         self.output_message.append('-------------------')
 
         try:
-            if not utils.is_uuid_like(pool_id):
-                self.output_message.append('Not a valid uuid: %s' % pool_id)
-                raise SystemExit(1)
-
-            pool = self.central_api.find_pool(self.context, {'id': pool_id})
+            pools = objects.PoolList()
+            if all_pools:
+                pools.extend(self.central_api.find_pools(self.context))
+            else:
+                if not uuidutils.is_uuid_like(pool_id):
+                    self.output_message.append(
+                        'Not a valid uuid: %s' % pool_id)
+                    raise SystemExit(1)
+                pools.append(
+                    self.central_api.find_pool(self.context, {'id': pool_id}))
 
             self.output_message.append(
                 yaml.dump(
-                    DesignateAdapter.render('YAML', pool),
+                    DesignateAdapter.render('YAML', pools),
                     default_flow_style=False
                 )
             )
@@ -131,7 +138,13 @@ class PoolCommands(base.Commands):
                 self.output_message.append('*********************************')
 
             for pool_data in pools_data:
-                self._create_or_update_pool(pool_data)
+                try:
+                    self._create_or_update_pool(pool_data)
+                except exceptions.DuplicatePool:
+                    raise exceptions.DuplicatePool(
+                        f'Pool {pool_data["name"]} already exist with id '
+                        f'{pool_data["id"]}. You cannot change id to an '
+                        'existing pool.')
 
             if delete:
                 pools = self.central_api.find_pools(self.context)
@@ -164,7 +177,7 @@ class PoolCommands(base.Commands):
     def _get_pool(self, pool_data):
         if 'id' in pool_data:
             pool_id = pool_data['id']
-            if not utils.is_uuid_like(pool_id):
+            if not uuidutils.is_uuid_like(pool_id):
                 self.output_message.append('Not a valid uuid: %s' % pool_id)
                 raise SystemExit(1)
 
@@ -258,7 +271,7 @@ class PoolCommands(base.Commands):
 
     @staticmethod
     def _load_config(filename):
-        with open(filename, 'r') as stream:
+        with open(filename) as stream:
             return yaml.safe_load(stream)
 
     @staticmethod
