@@ -11,35 +11,20 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-from oslo_log import log as logging
-
-from designate.objects.adapters.api_v2 import base
 from designate import objects
-LOG = logging.getLogger(__name__)
+from designate.objects.adapters.api_v2 import base
 
 
 class QuotaAPIv2Adapter(base.APIv2Adapter):
-
     ADAPTER_OBJECT = objects.Quota
-
     MODIFICATIONS = {
         'fields': {
-            'zones': {
-                'rename': 'domains',
+            'resource': {
                 'read_only': False
             },
-            'zone_records': {
-                'rename': 'domain_records',
+            'hard_limit': {
                 'read_only': False
             },
-            'zone_recordsets': {
-                'rename': 'domain_recordsets',
-                'read_only': False
-            },
-            'recordset_records': {
-                'read_only': False
-            },
-
         },
         'options': {
             'links': True,
@@ -50,9 +35,7 @@ class QuotaAPIv2Adapter(base.APIv2Adapter):
 
 
 class QuotaListAPIv2Adapter(base.APIv2Adapter):
-
     ADAPTER_OBJECT = objects.QuotaList
-
     MODIFICATIONS = {
         'options': {
             'links': True,
@@ -60,3 +43,24 @@ class QuotaListAPIv2Adapter(base.APIv2Adapter):
             'collection_name': 'quotas',
         }
     }
+
+    @classmethod
+    def render_list(cls, list_objects, *args, **kwargs):
+        r_list = {}
+        for obj in list_objects:
+            r_list[obj.resource] = obj.hard_limit
+        return r_list
+
+    @classmethod
+    def parse_list(cls, values, output_object, *args, **kwargs):
+        for key, value in values.items():
+            # Add the object to the list
+            output_object.append(
+                cls.ADAPTER_OBJECT.LIST_ITEM_TYPE.from_dict(
+                    {
+                        'resource': key,
+                        'hard_limit': value,
+                    }
+                )
+            )
+        return output_object
