@@ -15,10 +15,10 @@
 
 from copy import deepcopy
 
-from oslo_config import cfg
 from oslo_log import log
 from oslo_versionedobjects import exception as ovo_exc
 
+import designate.conf
 from designate import exceptions
 from designate.objects import base
 from designate.objects import fields
@@ -27,16 +27,15 @@ from designate.objects.validation_error import ValidationErrorList
 from designate import utils
 
 
+CONF = designate.conf.CONF
 LOG = log.getLogger(__name__)
 
-cfg.CONF.import_opt('supported_record_type', 'designate')
-
 
 @base.DesignateRegistry.register
 class RecordSet(base.DesignateObject, base.DictObjectMixin,
                 base.PersistentObjectMixin):
     def __init__(self, *args, **kwargs):
-        super(RecordSet, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
 
     @property
     def action(self):
@@ -125,7 +124,7 @@ class RecordSet(base.DesignateObject, base.DictObjectMixin,
                        % {'type': self.type})
             self._validate_fail(errors, err_msg)
 
-        if self.type not in cfg.CONF.supported_record_type:
+        if self.type not in CONF.supported_record_type:
             err_msg = ("'%(type)s' is not a supported record type"
                        % {'type': self.type})
             self._validate_fail(errors, err_msg)
@@ -152,6 +151,18 @@ class RecordSet(base.DesignateObject, base.DictObjectMixin,
             record_obj = record_cls()
             try:
                 record_obj.from_string(record.data)
+
+                # Special validation for SVCB records as we need to know the
+                # name of the recordset, which the records do not have access
+                # to from inside the record.
+                if self.type == 'SVCB' and "_dns" in self.name:
+                    alpns = record_obj.alpn.split('alpn=', 1)[1].split(',')
+                    for alpn in alpns:
+                        if alpn in ('h2', 'h3') and record_obj.dohpath is None:
+                            raise ValueError('DOH should be presented for '
+                                             'ALPN values h3 or h2 in dns '
+                                             'records.')
+
             # The from_string() method will throw a ValueError if there is not
             # enough data blobs
             except ValueError as e:
@@ -190,8 +201,10 @@ class RecordSet(base.DesignateObject, base.DictObjectMixin,
                 error_indexes.append(i)
 
             except Exception as e:
-                error_message = ('Provided object is not valid. Got a %s error'
-                    ' with message %s' % (type(e).__name__, str(e)))
+                error_message = (
+                        'Provided object is not valid. Got a %s error with '
+                        'message %s' % (type(e).__name__, str(e))
+                )
                 raise exceptions.InvalidObject(error_message)
 
             else:
@@ -202,7 +215,7 @@ class RecordSet(base.DesignateObject, base.DictObjectMixin,
 
         try:
             # Run the actual validate code
-            super(RecordSet, self).validate()
+            super().validate()
 
         except exceptions.InvalidObject as e:
             raise e
@@ -228,7 +241,7 @@ class RecordSet(base.DesignateObject, base.DictObjectMixin,
         self.records = old_records
 
     STRING_KEYS = [
-        'id', 'type', 'name', 'zone_id'
+        'id', 'type', 'name', 'zone_id', 'shard'
     ]
 
 
