@@ -13,7 +13,6 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-from oslo_config import cfg
 from oslo_log import log as logging
 
 from designate import exceptions
@@ -30,20 +29,19 @@ class StorageQuota(base.Quota):
     __plugin_name__ = 'storage'
 
     def __init__(self):
-        super(StorageQuota, self).__init__()
-
-        # TODO(kiall): Should this be tied to central's config?
-        storage_driver = cfg.CONF['service:central'].storage_driver
-        self.storage = storage.get_storage(storage_driver)
+        super().__init__()
+        self.storage = storage.get_storage()
 
     def _get_quotas(self, context, tenant_id):
+        """Internal Get Quotas used by get_quotas"""
         quotas = self.storage.find_quotas(context, {
             'tenant_id': tenant_id,
         })
 
-        return dict((q['resource'], q['hard_limit']) for q in quotas)
+        return {q['resource']: q['hard_limit'] for q in quotas}
 
     def get_quota(self, context, tenant_id, resource):
+        """Get Quota"""
         context = context.deepcopy()
         context.all_tenants = True
 
@@ -52,16 +50,20 @@ class StorageQuota(base.Quota):
             'resource': resource,
         })
 
-        return {resource: quota['hard_limit']}
+        return {
+            resource: quota['hard_limit']
+        }
 
     @transaction
     def set_quota(self, context, tenant_id, resource, hard_limit):
+        """Set Quota"""
         context = context.deepcopy()
         context.all_tenants = True
 
         if resource not in list(self.get_default_quotas(context).keys()):
-            raise exceptions.QuotaResourceUnknown("%s is not a valid quota "
-                                                  "resource" % resource)
+            raise exceptions.QuotaResourceUnknown(
+                f'{resource} is not a valid quota resource'
+            )
 
         try:
             self._create_quota(context, tenant_id, resource, hard_limit)
@@ -86,6 +88,7 @@ class StorageQuota(base.Quota):
 
     @transaction
     def reset_quotas(self, context, tenant_id):
+        """Reset Quotas"""
         context = context.deepcopy()
         context.all_tenants = True
 
