@@ -46,7 +46,7 @@ LOG = logging.getLogger(__name__)
 class Service(service.Service):
     def __init__(self, name, threads=None):
         threads = threads or 1000
-        super(Service, self).__init__(threads)
+        super().__init__(threads)
         self.name = name
         self.host = CONF.host
 
@@ -64,16 +64,16 @@ class Service(service.Service):
                      'name': self.name,
                      'version': version.version_info.version_string()
                  })
-        super(Service, self).start()
+        super().start()
 
     def stop(self, graceful=True):
         LOG.info('Stopping %(name)s service', {'name': self.name})
-        super(Service, self).stop(graceful)
+        super().stop(graceful)
 
 
 class RPCService(Service):
     def __init__(self, name, rpc_topic, threads=None):
-        super(RPCService, self).__init__(name, threads)
+        super().__init__(name, threads)
         LOG.debug("Creating RPC Server on topic '%s' for %s",
                   rpc_topic, self.name)
 
@@ -84,7 +84,7 @@ class RPCService(Service):
         self.rpc_topic = rpc_topic
 
     def start(self):
-        super(RPCService, self).start()
+        super().start()
         target = messaging.Target(topic=self.rpc_topic, server=self.host)
         self.rpc_server = rpc.get_server(target, self.endpoints)
         self.rpc_server.start()
@@ -93,15 +93,15 @@ class RPCService(Service):
     def stop(self, graceful=True):
         if self.rpc_server:
             self.rpc_server.stop()
-        super(RPCService, self).stop(graceful)
+        super().stop(graceful)
 
     def wait(self):
-        super(RPCService, self).wait()
+        super().wait()
 
 
 class WSGIService(Service):
     def __init__(self, app, name, listen, max_url_len=None):
-        super(WSGIService, self).__init__(name)
+        super().__init__(name)
         self.app = app
         self.name = name
 
@@ -116,6 +116,7 @@ class WSGIService(Service):
                 host=host,
                 port=port,
                 pool_size=CONF['service:api'].threads,
+                backlog=CONF.backlog,
                 use_ssl=sslutils.is_enabled(CONF),
                 max_url_len=max_url_len
             )
@@ -125,27 +126,29 @@ class WSGIService(Service):
     def start(self):
         for server in self.servers:
             server.start()
-        super(WSGIService, self).start()
+        super().start()
 
     def stop(self, graceful=True):
         for server in self.servers:
             server.stop()
-        super(WSGIService, self).stop(graceful)
+        super().stop(graceful)
 
     def wait(self):
         for server in self.servers:
             server.wait()
-        super(WSGIService, self).wait()
+        super().wait()
 
 
-class DNSService(object):
+class DNSService:
     _TCP_RECV_MAX_SIZE = 65535
 
-    def __init__(self, app, tg, listen, tcp_backlog, tcp_recv_timeout):
+    def __init__(self, app, tg, listen, tcp_backlog, tcp_keepidle,
+                 tcp_recv_timeout):
         self._running = threading.Event()
         self.app = app
         self.tg = tg
         self.tcp_backlog = tcp_backlog
+        self.tcp_keepidle = tcp_keepidle
         self.tcp_recv_timeout = tcp_recv_timeout
         self.listen = listen
 
@@ -169,7 +172,7 @@ class DNSService(object):
 
     def _start(self, host, port):
         sock_tcp = utils.bind_tcp(
-            host, port, self.tcp_backlog
+            host, port, self.tcp_backlog, self.tcp_keepidle
         )
         sock_udp = utils.bind_udp(
             host, port
@@ -227,7 +230,7 @@ class DNSService(object):
             # ensure no exceptions are generated from within.
             except socket.timeout:
                 pass
-            except socket.error as e:
+            except OSError as e:
                 if client:
                     client.close()
                 errname = errno.errorcode[e.args[0]]
@@ -294,8 +297,7 @@ class DNSService(object):
                 query = buf
 
                 # Call into the DNS Application itself with payload and addr
-                for response in self.app(
-                        {'payload': query, 'addr': addr}):
+                for response in self.app({'payload': query, 'addr': addr}):
 
                     # Send back a response only if present
                     if response is None:
@@ -314,7 +316,7 @@ class DNSService(object):
                     'port': port
                 }
             )
-        except socket.error as e:
+        except OSError as e:
             errname = errno.errorcode[e.args[0]]
             LOG.warning(
                 'Socket error %(err)s from: %(host)s:%(port)d',
@@ -342,8 +344,7 @@ class DNSService(object):
                 }
             )
         finally:
-            if client:
-                client.close()
+            client.close()
 
     def _dns_handle_udp(self, sock_udp):
         """Handle a DNS Query over UDP in a dedicated thread
@@ -374,7 +375,7 @@ class DNSService(object):
                                    payload)
             except socket.timeout:
                 pass
-            except socket.error as e:
+            except OSError as e:
                 errname = errno.errorcode[e.args[0]]
                 addr = addr or (None, 0)
                 LOG.warning(
