@@ -17,10 +17,10 @@ import copy
 from operator import attrgetter
 from unittest import mock
 
-import oslotest.base
-import testtools
 from oslo_log import log as logging
 from oslo_serialization import jsonutils
+import oslotest.base
+import testtools
 
 from designate import exceptions
 from designate import objects
@@ -39,6 +39,10 @@ class TestObject(objects.DesignateObject):
         'nested_list': fields.ObjectFields('TestObjectList', nullable=True),
     }
 
+    STRING_KEYS = [
+        'id', 'name'
+    ]
+
 
 @base.DesignateRegistry.register
 class TestObjectDict(TestObject, objects.DictObjectMixin):
@@ -64,6 +68,36 @@ class TestValidatableObject(objects.DesignateObject):
 
 
 class DesignateObjectTest(oslotest.base.BaseTestCase):
+    def test_obj_to_repr(self):
+        obj = TestObject.from_dict({
+            'id': 1, 'name': 'example'
+        })
+        self.assertEqual(
+            "<TestObject id:'1' name:'example'>",
+            repr(obj)
+        )
+
+    def test_obj_to_str(self):
+        obj = TestObject.from_dict({
+            'id': 1, 'name': 'example'
+        })
+        self.assertEqual(
+            "<TestObject id:'1' name:'example'>", str(obj)
+        )
+
+    def test_empty_obj_to_str(self):
+        self.assertEqual(
+            "<TestObject id:'None' name:'None'>", str(TestObject())
+        )
+
+    def test_record_to_str(self):
+        obj = objects.Record.from_dict({
+            'id': 1, 'recordset_id': '2', 'data': 'example'
+        })
+        self.assertEqual(
+            "<Record id:'1' recordset_id:'2' data:'example'>", str(obj)
+        )
+
     def test_obj_cls_from_name(self):
         cls = objects.DesignateObject.obj_cls_from_name('TestObject')
         self.assertEqual(TestObject, cls)
@@ -368,7 +402,7 @@ class DesignateObjectTest(oslotest.base.BaseTestCase):
     def test_obj_what_changed(self):
         obj = TestObject()
 
-        self.assertEqual(set([]), obj.obj_what_changed())
+        self.assertEqual(set(), obj.obj_what_changed())
 
         obj.name = "My Name"
 
@@ -613,16 +647,20 @@ class ListObjectMixinTest(oslotest.base.BaseTestCase):
             'designate_object.name': 'TestObjectList',
             'designate_object.data': {
                 'objects': [
-                    {'designate_object.changes': ['id'],
-                     'designate_object.data': {'id': 'One'},
-                     'designate_object.name': 'TestObject',
-                     'designate_object.namespace': 'designate',
-                     'designate_object.version': '1.0'},
-                    {'designate_object.changes': ['id'],
-                     'designate_object.data': {'id': 'Two'},
-                     'designate_object.name': 'TestObject',
-                     'designate_object.namespace': 'designate',
-                     'designate_object.version': '1.0'},
+                    {
+                        'designate_object.changes': ['id'],
+                        'designate_object.data': {'id': 'One'},
+                        'designate_object.name': 'TestObject',
+                        'designate_object.namespace': 'designate',
+                        'designate_object.version': '1.0'
+                    },
+                    {
+                        'designate_object.changes': ['id'],
+                        'designate_object.data': {'id': 'Two'},
+                        'designate_object.name': 'TestObject',
+                        'designate_object.namespace': 'designate',
+                        'designate_object.version': '1.0'
+                    },
                 ],
             },
             'designate_object.changes': ['objects'],
@@ -706,16 +744,20 @@ class ListObjectMixinTest(oslotest.base.BaseTestCase):
             'designate_object.name': 'TestObjectList',
             'designate_object.data': {
                 'objects': [
-                    {'designate_object.changes': ['id'],
-                     'designate_object.data': {'id': 'One'},
-                     'designate_object.name': 'TestObject',
-                     'designate_object.namespace': 'designate',
-                     'designate_object.version': '1.0'},
-                    {'designate_object.changes': ['id'],
-                     'designate_object.data': {'id': 'Two'},
-                     'designate_object.name': 'TestObject',
-                     'designate_object.namespace': 'designate',
-                     'designate_object.version': '1.0'},
+                    {
+                        'designate_object.changes': ['id'],
+                        'designate_object.data': {'id': 'One'},
+                        'designate_object.name': 'TestObject',
+                        'designate_object.namespace': 'designate',
+                        'designate_object.version': '1.0'
+                    },
+                    {
+                        'designate_object.changes': ['id'],
+                        'designate_object.data': {'id': 'Two'},
+                        'designate_object.name': 'TestObject',
+                        'designate_object.namespace': 'designate',
+                        'designate_object.version': '1.0'
+                    },
                 ],
             },
             'designate_object.changes': ['objects'],
@@ -740,24 +782,28 @@ class ListObjectMixinTest(oslotest.base.BaseTestCase):
             'designate_object.changes': ['objects'],
             'designate_object.data': {
                 'objects': [
-                    {'designate_object.changes': ['nested'],
-                     'designate_object.data': {'nested':
-                         {
-                             'designate_object.changes': [
-                                 'id'],
-                             'designate_object.data': {
-                                 'id': 'Two'},
-                             'designate_object.name': 'TestObject',
-                             'designate_object.namespace': 'designate',
-                             'designate_object.version': '1.0'}},
-                     'designate_object.name': 'TestObject',
-                     'designate_object.namespace': 'designate',
-                     'designate_object.version': '1.0'},
-                    {'designate_object.changes': ['id'],
-                     'designate_object.data': {'id': 'Two'},
-                     'designate_object.name': 'TestObject',
-                     'designate_object.namespace': 'designate',
-                     'designate_object.version': '1.0'}]},
+                    {
+                        'designate_object.changes': ['nested'],
+                        'designate_object.data': {'nested':
+                            {
+                                'designate_object.changes': ['id'],
+                                'designate_object.data': {'id': 'Two'},
+                                'designate_object.name': 'TestObject',
+                                'designate_object.namespace': 'designate',
+                                'designate_object.version': '1.0'}
+                        },
+                        'designate_object.name': 'TestObject',
+                        'designate_object.namespace': 'designate',
+                        'designate_object.version': '1.0'},
+                    {
+                        'designate_object.changes': ['id'],
+                        'designate_object.data': {'id': 'Two'},
+                        'designate_object.name': 'TestObject',
+                        'designate_object.namespace': 'designate',
+                        'designate_object.version': '1.0'
+                    }
+                ]
+            },
             'designate_object.namespace': 'designate',
             'designate_object.version': '1.0'}
 
@@ -775,7 +821,7 @@ class ListObjectMixinTest(oslotest.base.BaseTestCase):
         obj.obj_reset_changes()
 
         changes = obj.obj_what_changed()
-        expected = set([])
+        expected = set()
 
         self.assertEqual(expected, changes)
 
