@@ -13,38 +13,55 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.mport threading
+
+
 from unittest import mock
 
-from oslo_config import cfg
 from oslo_config import fixture as cfg_fixture
 import oslo_messaging as messaging
 import oslotest.base
 
 from designate import backend
 from designate.central import rpcapi as central_rpcapi
+import designate.conf
 from designate import exceptions
 from designate import objects
+from designate import policy
+from designate import rpc
 import designate.service
 from designate import storage
 import designate.tests
-from designate.tests import fixtures
+from designate.tests import base_fixtures
 from designate.worker import processing
 from designate.worker import service
 
-CONF = cfg.CONF
+
+CONF = designate.conf.CONF
 
 
-class TestService(oslotest.base.BaseTestCase):
-    def setUp(self):
-        super(TestService, self).setUp()
-        self.stdlog = fixtures.StandardLogging()
+class WorkerServiceTest(oslotest.base.BaseTestCase):
+    @mock.patch.object(policy, 'init')
+    @mock.patch.object(rpc, 'get_client')
+    @mock.patch.object(rpc, 'init')
+    @mock.patch.object(rpc, 'initialized')
+    def setUp(self, mock_rpc_initialized, mock_rpc_init, mock_rpc_get_client,
+              mock_policy_init):
+        super().setUp()
+
+        mock_rpc_initialized.return_value = False
+
+        self.stdlog = base_fixtures.StandardLogging()
         self.useFixture(self.stdlog)
-        conf = self.useFixture(cfg_fixture.Config(CONF))
-        conf.conf([], project='designate')
+        self.useFixture(cfg_fixture.Config(CONF))
+
         self.context = mock.Mock()
         self.zone = mock.Mock()
         self.service = service.Service()
 
+        mock_policy_init.assert_called_once()
+        mock_rpc_initialized.assert_called_once()
+        mock_rpc_init.assert_called_once()
+
     @mock.patch.object(designate.service.RPCService, 'start')
     def test_service_start(self, mock_rpc_start):
         self.service.start()
@@ -60,6 +77,10 @@ class TestService(oslotest.base.BaseTestCase):
     def test_service_name(self):
         self.assertEqual('worker', self.service.service_name)
 
+    @mock.patch.object(policy, 'init', mock.Mock())
+    @mock.patch.object(rpc, 'get_client', mock.Mock())
+    @mock.patch.object(rpc, 'init', mock.Mock())
+    @mock.patch.object(rpc, 'initialized', mock.Mock(return_value=False))
     def test_worker_rpc_topic(self):
         CONF.set_override('topic', 'test-topic', 'service:worker')
 
@@ -68,6 +89,7 @@ class TestService(oslotest.base.BaseTestCase):
         self.assertEqual('test-topic', self.service.rpc_topic)
         self.assertEqual('worker', self.service.service_name)
 
+    @mock.patch.object(rpc, 'get_client', mock.Mock())
     def test_central_api(self):
         self.assertIsNone(self.service._central_api)
         self.assertIsInstance(self.service.central_api,
@@ -179,11 +201,22 @@ class TestService(oslotest.base.BaseTestCase):
 
     def test_delete_zone(self):
         self.service._do_zone_action = mock.Mock()
+        self.zone_params = {}
 
         self.service.delete_zone(self.context, self.zone)
 
         self.service._do_zone_action.assert_called_with(
-            self.context, self.zone
+            self.context, self.zone, self.zone_params
+        )
+
+    def test_delete_zone_hard(self):
+        self.service._do_zone_action = mock.Mock()
+        self.zone_params = {'hard_delete': True}
+
+        self.service.delete_zone(self.context, self.zone, hard_delete=True)
+
+        self.service._do_zone_action.assert_called_with(
+            self.context, self.zone, self.zone_params
         )
 
     def test_update_zone(self):
@@ -204,18 +237,21 @@ class TestService(oslotest.base.BaseTestCase):
         pool.also_notifies = mock.MagicMock()
         pool.also_notifies.__iter__.return_value = []
         self.service.get_pool.return_value = pool
+        self.zone_params = {}
 
-        self.service._do_zone_action(self.context, self.zone)
+        self.service._do_zone_action(self.context, self.zone,
+                                     self.zone_params)
 
         mock_zone_action.assert_called_with(
             self.service.executor,
             self.context,
             pool,
             self.zone,
-            self.zone.action
+            self.zone.action,
+            self.zone_params
         )
 
-        self.service._executor.run.assert_called_with([mock_zone_action()])
+        self.service._executor.run.assert_has_calls(mock_zone_action(), list())
 
     @mock.patch.object(service.zonetasks, 'ZoneAction')
     @mock.patch.object(service.zonetasks, 'SendNotify')
@@ -227,22 +263,25 @@ class TestService(oslotest.base.BaseTestCase):
         pool = mock.Mock()
         pool.also_notifies = mock.MagicMock()
         pool.also_notifies.__iter__.return_value = [
-            mock.Mock(host='192.168.1.1', port=53),
+            mock.Mock(host='192.0.2.1', port=53),
         ]
         self.service.get_pool.return_value = pool
+        self.zone_params = {}
 
-        self.service._do_zone_action(self.context, self.zone)
+        self.service._do_zone_action(self.context, self.zone,
+                                     self.zone_params)
 
         mock_zone_action.assert_called_with(
             self.service.executor,
             self.context,
             pool,
             self.zone,
-            self.zone.action
+            self.zone.action,
+            self.zone_params
         )
 
-        self.service._executor.run.assert_called_with(
-            [mock_zone_action(), mock_send_notify()]
+        self.service._executor.run.assert_has_calls(
+            mock_zone_action(), [mock_send_notify()]
         )
 
     def test_get_pool(self):
@@ -309,13 +348,13 @@ class TestService(oslotest.base.BaseTestCase):
         zone = mock.Mock()
 
         self.service.get_serial_number(
-            self.context, zone, 'localhost', 53
+            self.context, zone, '203.0.113.1', 53
         )
 
         mock_get_serial_number.assert_called_with(
             self.service.executor,
             self.context,
             zone,
-            'localhost',
+            '203.0.113.1',
             53
         )
