@@ -15,13 +15,13 @@
 # under the License.
 import time
 
-from oslo_config import cfg
 from oslo_log import log as logging
 import oslo_messaging as messaging
 
 from designate import backend
 from designate.central import rpcapi as central_api
 from designate.common.decorators import rpc
+import designate.conf
 from designate.context import DesignateContext
 from designate import exceptions
 from designate import service
@@ -31,10 +31,10 @@ from designate.worker.tasks import zone as zonetasks
 
 
 LOG = logging.getLogger(__name__)
-CONF = cfg.CONF
+CONF = designate.conf.CONF
 
 
-class AlsoNotifyTask(object):
+class AlsoNotifyTask:
     """
     Placeholder to define options for also_notify targets
     """
@@ -42,7 +42,7 @@ class AlsoNotifyTask(object):
 
 
 class Service(service.RPCService):
-    RPC_API_VERSION = '1.1'
+    RPC_API_VERSION = '1.2'
 
     target = messaging.Target(version=RPC_API_VERSION)
 
@@ -53,9 +53,9 @@ class Service(service.RPCService):
         self._executor = None
         self._pools_map = None
 
-        super(Service, self).__init__(
-            self.service_name, cfg.CONF['service:worker'].topic,
-            threads=cfg.CONF['service:worker'].threads,
+        super().__init__(
+            self.service_name, CONF['service:worker'].topic,
+            threads=CONF['service:worker'].threads,
         )
 
     @property
@@ -111,8 +111,7 @@ class Service(service.RPCService):
     @property
     def storage(self):
         if not self._storage:
-            storage_driver = cfg.CONF['service:worker'].storage_driver
-            self._storage = storage.get_storage(storage_driver)
+            self._storage = storage.get_storage()
         return self._storage
 
     @property
@@ -135,28 +134,28 @@ class Service(service.RPCService):
         return self.pools_map[pool_id]
 
     def start(self):
-        super(Service, self).start()
+        super().start()
         LOG.info('Started worker')
 
     def stop(self, graceful=True):
-        super(Service, self).stop(graceful)
+        super().stop(graceful)
 
-    def _do_zone_action(self, context, zone):
+    def _do_zone_action(self, context, zone, zone_params=None):
         pool = self.get_pool(zone.pool_id)
-        all_tasks = [
-            zonetasks.ZoneAction(self.executor, context, pool, zone,
-                                 zone.action)
-        ]
-
+        zone_action = zonetasks.ZoneAction(
+            self.executor, context, pool, zone, zone.action, zone_params)
+        all_tasks_result = self.executor.run(zone_action)
         # Send a NOTIFY to each also-notifies
+        also_notifies_tasks = list()
         for also_notify in pool.also_notifies:
             notify_target = AlsoNotifyTask()
             notify_target.options = {'host': also_notify.host,
                                      'port': also_notify.port}
-            all_tasks.append(zonetasks.SendNotify(self.executor,
+            also_notifies_tasks.append(zonetasks.SendNotify(self.executor,
                                                   zone,
                                                   notify_target))
-        return self.executor.run(all_tasks)
+        all_tasks_result.extend(self.executor.run(also_notifies_tasks))
+        return all_tasks_result
 
     @rpc.expected_exceptions()
     def create_zone(self, context, zone):
@@ -177,13 +176,17 @@ class Service(service.RPCService):
         self._do_zone_action(context, zone)
 
     @rpc.expected_exceptions()
-    def delete_zone(self, context, zone):
+    def delete_zone(self, context, zone, hard_delete=False):
         """
         :param context: Security context information.
         :param zone: Zone to be deleted
+        :param hard_delete: Zone resources (files) to be deleted or not
         :return: None
         """
-        self._do_zone_action(context, zone)
+        zone_params = {}
+        if hard_delete:
+            zone_params.update({'hard_delete': True})
+        self._do_zone_action(context, zone, zone_params)
 
     @rpc.expected_exceptions()
     def recover_shard(self, context, begin, end):
